# Calendar Module

The `solcadre.calendar` module generates localized Solcadre calendars and provides helpers to map arbitrary datetimes to Solcadre dates and times.

::: solcadre.calendar
    options:
      show_root_heading: true
      show_root_toc_entry: true
      show_source: true
      heading_level: 2

## Calendar

::: solcadre.calendar.Calendar
    options:
      show_root_heading: true
      show_root_toc_entry: true
      show_source: true
      heading_level: 2

## Exceptions

::: solcadre.calendar.InvalidLatitude
    options:
      show_root_heading: true
      show_root_toc_entry: true
      show_source: true
      heading_level: 2

